##  Table of Contents
  * [Getting Started](https://help.sap.com/docs/leanix/ea/getting-started)
    * [SAP LeanIX for Enterprise Architects](https://help.sap.com/docs/leanix/ea/for-enterprise-architects)
      * [Set Up User Access](https://help.sap.com/docs/leanix/ea/set-up-user-access)
      * [Getting Data into Your Workspace](https://help.sap.com/docs/leanix/ea/get-data-into-workspace)
      * [Use Cases](https://help.sap.com/docs/leanix/ea/use-cases)
    * [SAP LeanIX for Application and Business Owners](https://help.sap.com/docs/leanix/ea/for-application-and-business-owners)
    * [Navigating SAP LeanIX](https://help.sap.com/docs/leanix/ea/navigation)
    * [SAP LeanIX Resources](https://help.sap.com/docs/leanix/ea/resources)
    * [FAQs](https://help.sap.com/docs/leanix/ea/faqs)
    * [Contact Support](https://help.sap.com/docs/leanix/ea/contact-support)
    * [Onboarding Journey](https://help.sap.com/docs/leanix/ea/onboarding-journey)
    * [Migration of SAP LeanIX Academy Courses to SAP Learning](https://help.sap.com/docs/leanix/ea/migration-of-sap-leanix-academy-courses-to-sap-learning)
  * [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model)
    * [General Modeling Guidelines](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines)
      * [Using Tags and Custom Fields](https://help.sap.com/docs/leanix/ea/tags-and-custom-fields)
      * [Using Relations](https://help.sap.com/docs/leanix/ea/relations)
      * [Modeling and Reports](https://help.sap.com/docs/leanix/ea/modeling-and-reports)
    * [Fact Sheet Modeling Guidelines](https://help.sap.com/docs/leanix/ea/fact-sheet-modeling-guidelines)
      * [Application Modeling Guidelines](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines)
        * [Microservice Modeling Guidelines](https://help.sap.com/docs/leanix/ea/microservice-modeling-guidelines)
        * [AI Agent Modeling Guidelines](https://help.sap.com/docs/leanix/ea/ai-agent-modeling-guidelines)
      * [Business Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/business-capability-modeling-guidelines)
      * [Business Context Modeling Guidelines](https://help.sap.com/docs/leanix/ea/business-context-modeling-guidelines)
        * [ESG Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines)
      * [Data Object Modeling Guidelines](https://help.sap.com/docs/leanix/ea/data-object-modeling-guidelines)
      * [Initiative Modeling Guidelines](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines)
      * [Interface Modeling Guidelines](https://help.sap.com/docs/leanix/ea/interface-modeling-guidelines)
      * [IT Component Modeling Guidelines](https://help.sap.com/docs/leanix/ea/it-component-modeling-guidelines)
      * [Objective Modeling Guidelines](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines)
      * [Organization Modeling Guidelines](https://help.sap.com/docs/leanix/ea/organization-modeling-guidelines)
      * [Platform Modeling Guidelines](https://help.sap.com/docs/leanix/ea/platform-modeling-guidelines)
      * [Provider Modeling Guidelines](https://help.sap.com/docs/leanix/ea/provider-modeling-guidelines)
      * [Tech Category Modeling Guidelines](https://help.sap.com/docs/leanix/ea/tech-category-modeling-guidelines)
      * [System Modeling Guidelines](https://help.sap.com/docs/leanix/ea/system-modeling-guidelines)
    * [Modeling Best Practices](https://help.sap.com/docs/leanix/ea/modeling-best-practices)
      * [SAP Modeling Best Practices](https://help.sap.com/docs/leanix/ea/sap-modeling-best-practices)
        * [Modeling SAP Cloud Solutions](https://help.sap.com/docs/leanix/ea/modeling-sap-cloud-solutions)
        * [Modeling SAP S/4HANA](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana)
        * [Modeling SAP BTP](https://help.sap.com/docs/leanix/ea/modeling-sap-btp)
        * [Modeling SAP Interfaces and External Partners](https://help.sap.com/docs/leanix/ea/modeling-sap-interfaces-and-external-partners)
        * [Modeling SAP ERP 6.0](https://help.sap.com/docs/leanix/ea/modeling-sap-erp-60)
      * [Microsoft Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/microsoft-applications-modeling-best-practices)
      * [Google Cloud Platform Modeling Best Practices](https://help.sap.com/docs/leanix/ea/google-cloud-platform-modeling-best-practices)
      * [Salesforce Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/salesforce-applications-modeling-best-practices)
      * [AWS Applications Modeling Best Practices](https://help.sap.com/docs/leanix/ea/aws-applications-modeling-best-practices)
    * [Meta Model Extensions](https://help.sap.com/docs/leanix/ea/meta-model-extensions)
      * [AI Governance Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension)
      * [Digital Operational Resilience Act (DORA) Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-dora-extension)
        * [Digital Operational Resilience Act (DORA) Attributes](https://help.sap.com/docs/leanix/ea/digital-operational-resilience-act-dora-attributes)
      * [Application Total Cost of Ownership (TCO) Extension](https://help.sap.com/docs/leanix/ea/application-total-cost-of-ownership-extension)
      * [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model)
      * [IT Component Naming Rule Extension](https://help.sap.com/docs/leanix/ea/it-component-naming-rule-extension)
      * [SAP Suggestions in Your Landscape Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/sap-suggestions)
    * [Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3)
      * [Delta to Meta Model v3](https://help.sap.com/docs/leanix/ea/delta-to-meta-model-v3)
      * [Configure Workspace for Meta Model v4](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4)
      * [Modeling Guidelines (Meta Model v3)](https://help.sap.com/docs/leanix/ea/modeling-guidelines-v3)
      * [Modeling: Application vs. IT component](https://help.sap.com/docs/leanix/ea/application-vs-it-component-v3)
      * [Modeling: Objectives and Transformation Items (Projects) (Meta Model v3)](https://help.sap.com/docs/leanix/ea/objectives-and-transformations-items-v3)
      * [Modeling: Business Capabilities (Meta Model v3)](https://help.sap.com/docs/leanix/ea/business-capabilities-modeling-v3)
      * [Modeling: Data Object (Meta Model v3)](https://help.sap.com/docs/leanix/ea/data-object-modeling-v3)
      * [Modeling: Interfaces (Meta Model v3)](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3)
      * [Modeling: IT Components / Hosting (Meta Model v3)](https://help.sap.com/docs/leanix/ea/it-components-hosting-modeling-v3)
      * [Modeling: Middleware and APIs (Meta Model v3)](https://help.sap.com/docs/leanix/ea/middleware-and-apis-modeling-v3)
      * [Modeling: Process (Meta Model v3)](https://help.sap.com/docs/leanix/ea/process-modeling-v3)
      * [Modeling: Project Fact Sheet (Meta Model v3)](https://help.sap.com/docs/leanix/ea/project-modeling-v3)
      * [Modeling: Tech Category (Meta Model v3)](https://help.sap.com/docs/leanix/ea/tech-category-modeling-v3)
      * [Modeling: User Group (Meta Model V3 )](https://help.sap.com/docs/leanix/ea/user-group-modeling-v3)
      * [Optional Features: Tech Platform Fact Sheet (Meta Model v3)](https://help.sap.com/docs/leanix/ea/tech-platform-fact-sheet-v3)
  * [Use Cases and Methodologies](https://help.sap.com/docs/leanix/ea/use-cases-methodologies)
    * [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment)
      * [Step 1: Add Data](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-define-scope)
        * [Add Applications](https://help.sap.com/docs/leanix/ea/add-applications)
        * [Add Business Capabilities](https://help.sap.com/docs/leanix/ea/add-business-capabilities)
        * [Add Organizations](https://help.sap.com/docs/leanix/ea/add-organizations)
        * [Add Relations](https://help.sap.com/docs/leanix/ea/add-relations)
      * [Step 2: Collect and Maintain Data](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-enrich-data)
        * [Identify and Assign Fact Sheet Owners](https://help.sap.com/docs/leanix/ea/assign-fact-sheet-owners)
        * [Configure Data Quality Controls](https://help.sap.com/docs/leanix/ea/configure-data-quality-controls)
        * [Onboard Fact Sheet Owners and Collect Data](https://help.sap.com/docs/leanix/ea/collect-data-from-fact-sheet-owners)
        * [Key Attributes for Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/key-attributes-for-application-portfolio-assessment)
      * [Step 3. Assess Your Application Portfolio](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-assess-portfolio)
    * [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization)
      * [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-rationalization-understand-strategy)
      * [Step 2: Scope Applications](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications)
      * [Step 3: Enrich Data](https://help.sap.com/docs/leanix/ea/application-rationalization-enrich-data)
      * [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-rationalization-evaluate-data)
      * [Step 5: Create a Rationalization Roadmap](https://help.sap.com/docs/leanix/ea/application-rationalization-create-roadmap)
      * [Step 6: Start the Rationalization Initiative](https://help.sap.com/docs/leanix/ea/application-rationalization-start-initiative)
      * [Step 7: Track and Report](https://help.sap.com/docs/leanix/ea/application-rationalization-track-report)
    * [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization)
      * [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy)
      * [Step 2: Scope Applications](https://help.sap.com/docs/leanix/ea/application-modernization-scope-applications)
      * [Step 3: Collect Data](https://help.sap.com/docs/leanix/ea/application-modernization-collect-data)
      * [Step 4: Evaluate Data](https://help.sap.com/docs/leanix/ea/application-modernization-evaluate-data)
      * [Step 5: Plan Transformations and Create a Roadmap](https://help.sap.com/docs/leanix/ea/application-modernization-transformations-and-roadmap)
      * [Step 6: Start Modernization](https://help.sap.com/docs/leanix/ea/application-modernization-start-initiative)
      * [Step 7: Track and Report](https://help.sap.com/docs/leanix/ea/application-modernization-track-report)
    * [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation)
      * [Phase 0. Foundation: Transformation Strategy and Setup](https://help.sap.com/docs/leanix/ea/erp-transformation-foundation)
      * [Phase 1. Discover: Achieve Architecture Transparency](https://help.sap.com/docs/leanix/ea/erp-transformation-discover)
      * [Phase 2. Prepare the Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-prepare)
      * [Phase 3. Explore: Define the To-Be Architecture](https://help.sap.com/docs/leanix/ea/erp-transformation-explore)
      * [Phase 4. Realize, Deploy, and Run: Transformations and Monitoring](https://help.sap.com/docs/leanix/ea/erp-transformation-realize-deploy-run)
    * [SAP ERP Transformation with Integrated Toolchain](https://help.sap.com/docs/leanix/ea/erp-transformation-with-rise-with-sap-integrated-toolchain)
    * [Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management)
      * [Step 1: Bring Software Assets Information to SAP LeanIX](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-import-software-assets)
      * [Step 2: Enrich Data](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-enrich-data)
      * [Step 3: Discover and Prioritize Technology Obsolescence Risks](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-discover-prioritize-risks)
      * [Step 4: Plan and Manage Risk Mitigation Initiatives](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-plan-manage-mitigation)
      * [Step 5: Monitor, Measure, and Report Risk Mitigation Efforts](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-monitor-mitigation)
      * [Advanced Practices](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management-advanced)
    * [AI Governance](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption)
      * [Step 1: Collect Data](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-collect-information)
      * [Step 2: Assess AI Potential and Usage](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-assess-potential)
      * [Step 3: Evaluate AI-Related Risks](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-evaluate-risks)
      * [Step 4: Standardize AI Usage](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-standardize-usage)
      * [Step 5: Create AI-Related Transformations](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-plan-transformations)
      * [Step 6: Track and Report](https://help.sap.com/docs/leanix/ea/step-6-track-and-report)
    * [Portfolio Assessment Methodologies](https://help.sap.com/docs/leanix/ea/portfolio-assessment-methodologies)
      * [Gartner® TIME Framework](https://help.sap.com/docs/leanix/ea/time)
      * [6R Framework](https://help.sap.com/docs/leanix/ea/6r)
      * [Pace Layering Framework](https://help.sap.com/docs/leanix/ea/pace-layering)
        * [Modeling Pace Layers](https://help.sap.com/docs/leanix/ea/modeling-pace-layers)
        * [Application of Pace Layering in Assessments](https://help.sap.com/docs/leanix/ea/application-of-pace-layering-in-assessments)
  * [User Guide](https://help.sap.com/docs/leanix/ea/user-guide)
    * [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards)
      * [Dashboard Modeling](https://help.sap.com/docs/leanix/ea/dashboard-modeling)
      * [Application Portfolio Management Dashboard](https://help.sap.com/docs/leanix/ea/application-portfolio-management-dashboard)
      * [Fact Sheet Owner Onboarding Dashboard](https://help.sap.com/docs/leanix/ea/fact-sheet-owner-onboarding-dashboard)
      * [Application Portfolio Management Onboarding Dashboard for Enterprise Architects](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects)
        * [Onboarding Guide for SAP LeanIX Application Portfolio Management](https://help.sap.com/docs/leanix/ea/onboarding-guide-application-portfolio-management)
      * [Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/architecture-executive-dashboard)
        * [Configuring the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/configure-architecture-executive-dashboard)
        * [Navigating the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/navigate-architecture-executive-dashboard)
        * [Using and Analyzing Executive KPIs](https://help.sap.com/docs/leanix/ea/kpi-insights)
        * [Executive KPIs](https://help.sap.com/docs/leanix/ea/executive-kpis)
    * [Inventory](https://help.sap.com/docs/leanix/ea/inventory)
      * [Fact Sheets](https://help.sap.com/docs/leanix/ea/fact-sheets)
      * [Creating Fact Sheets](https://help.sap.com/docs/leanix/ea/creating-fact-sheets)
      * [Adding and Editing Data in Fact Sheets](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets)
      * [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view)
      * [Collaborating and Managing Data in Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets)
      * [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file)
      * [Exporting Fact Sheet Data as Excel File](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file)
      * [Increasing Your Data Quality](https://help.sap.com/docs/leanix/ea/increasing-your-data-quality)
        * [Fact Sheet Completeness](https://help.sap.com/docs/leanix/ea/fact-sheet-completeness)
        * [Fact Sheet Subscription](https://help.sap.com/docs/leanix/ea/fact-sheet-subscription)
        * [Quality Seal](https://help.sap.com/docs/leanix/ea/quality-seal)
        * [Mandatory Attributes](https://help.sap.com/docs/leanix/ea/mandatory-attributes)
        * [Data Quality Insights](https://help.sap.com/docs/leanix/ea/data-quality-insights)
      * [Searching and Filtering in the Inventory](https://help.sap.com/docs/leanix/ea/searching-and-filtering-in-inventory)
        * [Advanced Filter Options](https://help.sap.com/docs/leanix/ea/advanced-filter-options)
        * [Strict Filtering](https://help.sap.com/docs/leanix/ea/strict-filtering)
      * [Tags](https://help.sap.com/docs/leanix/ea/tags)
      * [Archiving, Deleting and Recovering Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets)
    * [Reports](https://help.sap.com/docs/leanix/ea/reports)
      * [Using Reports](https://help.sap.com/docs/leanix/ea/using-reports)
      * [Report Views](https://help.sap.com/docs/leanix/ea/report-views)
        * [Views Aggregation](https://help.sap.com/docs/leanix/ea/views-aggregation)
      * [Landscape Report](https://help.sap.com/docs/leanix/ea/landscape-report)
      * [Matrix Report](https://help.sap.com/docs/leanix/ea/matrix-report)
      * [Portfolio Report](https://help.sap.com/docs/leanix/ea/portfolio-report)
      * [Roadmap Report](https://help.sap.com/docs/leanix/ea/roadmap-report)
      * [Radar Report](https://help.sap.com/docs/leanix/ea/radar-report)
      * [Circle Map Report](https://help.sap.com/docs/leanix/ea/circle-map-report)
      * [Other Reports](https://help.sap.com/docs/leanix/ea/other-reports)
      * [Custom Reports: Workspace Best Practice](https://help.sap.com/docs/leanix/ea/workspace-best-practice-report)
      * [Cost Management](https://help.sap.com/docs/leanix/ea/cost-management)
      * [Embedding a Report in SharePoint](https://help.sap.com/docs/leanix/ea/embedding-report-in-sharepoint)
    * [Diagrams](https://help.sap.com/docs/leanix/ea/diagrams)
      * [Creating Diagrams and Adding Basic Elements](https://help.sap.com/docs/leanix/ea/creating-your-first-diagram-and-adding-basic-elements)
      * [Viewing and Analyzing Diagrams](https://help.sap.com/docs/leanix/ea/viewing-and-analyzing-diagrams)
      * [Managing Diagram Versions, Importing, and Exporting](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting)
      * [Free Draw Diagrams](https://help.sap.com/docs/leanix/ea/free-draw)
      * [Data Flow Diagrams](https://help.sap.com/docs/leanix/ea/data-flow)
      * [Diagram Templates](https://help.sap.com/docs/leanix/ea/diagram-templates)
        * [Creating and Editing Diagram Templates](https://help.sap.com/docs/leanix/ea/creating-and-editing-diagram-templates)
        * [Previewing Templates and Creating Diagrams from Templates](https://help.sap.com/docs/leanix/ea/previewing-templates-and-creating-diagrams-from-templates)
      * [Styles and Patterns](https://help.sap.com/docs/leanix/ea/styles-and-patterns)
        * [Fact Sheet Shape Templates](https://help.sap.com/docs/leanix/ea/fact-sheet-shape-templates)
        * [SAP BTP Reference Architecture Templates](https://help.sap.com/docs/leanix/ea/sap-btp-reference-architecture-templates)
      * [Lucidchart Integration](https://help.sap.com/docs/leanix/ea/lucidchart-integration)
    * [Collaboration](https://help.sap.com/docs/leanix/ea/collaboration)
      * [Surveys](https://help.sap.com/docs/leanix/ea/surveys)
        * [Creating a Survey](https://help.sap.com/docs/leanix/ea/creating-survey)
        * [Sending Out the Surveys](https://help.sap.com/docs/leanix/ea/sending-out-surveys)
        * [Responding to Surveys](https://help.sap.com/docs/leanix/ea/responding-to-surveys)
        * [Managing Surveys and Viewing Results](https://help.sap.com/docs/leanix/ea/managing-surveys-and-viewing-results)
        * [Extended Guide on Survey Features](https://help.sap.com/docs/leanix/ea/extended-guide-on-survey-features)
        * [Calculated Fields in Surveys](https://help.sap.com/docs/leanix/ea/calculated-fields-in-surveys)
      * [To-Dos](https://help.sap.com/docs/leanix/ea/to-dos)
    * [AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities)
      * [Base AI Capabilities](https://help.sap.com/docs/leanix/ea/base-ai-capabilities)
      * [Inventory Builder](https://help.sap.com/docs/leanix/ea/inventory-builder)
        * [Sample Prompts for the Inventory Builder](https://help.sap.com/docs/leanix/ea/sample-prompts-for-inventory-builder)
      * [Joule in SAP LeanIX](https://help.sap.com/docs/leanix/ea/joule-in-sap-leanix)
    * [AI Agent Hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub)
      * [AI Agent Hub Dashboard](https://help.sap.com/docs/leanix/ea/ai-agent-hub-dashboard)
      * [Reports for AI Agents](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents)
      * [SAP Suggestions in Reports](https://help.sap.com/docs/leanix/ea/sap-suggestions-in-reports)
      * [Calculations for AI Agents](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents)
    * [MCP Server](https://help.sap.com/docs/leanix/ea/mcp-server)
      * [Connecting to the MCP Server](https://help.sap.com/docs/leanix/ea/connecting-to-mcp-server)
    * [Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views)
    * [Presentations](https://help.sap.com/docs/leanix/ea/presentations)
    * [Collections](https://help.sap.com/docs/leanix/ea/collections)
    * [Notifications](https://help.sap.com/docs/leanix/ea/notifications)
    * [User Profile](https://help.sap.com/docs/leanix/ea/user-profile)
  * [Administrator Guide](https://help.sap.com/docs/leanix/ea/administrator-guide)
    * [Workspace Provisioning from SAP for Me](https://help.sap.com/docs/leanix/ea/workspace-provisioning-from-sap-for-me)
      * [SAP for Me Super/Cloud Admin for Workspace Provisioning](https://help.sap.com/docs/leanix/ea/sap-for-me-super-cloud-admin-for-workspace-provisioning)
      * [Provisioning SAP LeanIX from SAP for Me (NGCS)](https://help.sap.com/docs/leanix/ea/provisioning-sap-leanix-workspace)
      * [Provisioning SAP LeanIX from SAP for Me (classic)](https://help.sap.com/docs/leanix/ea/workspace-provisioning)
    * [Workspace Administration](https://help.sap.com/docs/leanix/ea/workspace-administration)
      * [Workspace Settings Overview](https://help.sap.com/docs/leanix/ea/workspace-settings-overview)
      * [Manage Workspace Access](https://help.sap.com/docs/leanix/ea/manage-workspace-access)
      * [Status Pages and Status Emails](https://help.sap.com/docs/leanix/ea/status-pages-and-status-emails)
      * [Production and Sandbox Workspaces](https://help.sap.com/docs/leanix/ea/production-and-sandbox-workspaces)
      * [Monitoring the Usage and Adoption of SAP LeanIX](https://help.sap.com/docs/leanix/ea/monitor-usage-and-adoption)
      * [Password Rules](https://help.sap.com/docs/leanix/ea/password-rules)
    * [Basic Settings](https://help.sap.com/docs/leanix/ea/basic-settings)
      * [Branding Settings](https://help.sap.com/docs/leanix/ea/branding-settings)
      * [General Settings](https://help.sap.com/docs/leanix/ea/general-settings)
      * [Meta Model Configuration](https://help.sap.com/docs/leanix/ea/meta-model-configuration)
        * [Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/fact-sheet-fields)
        * [Fact Sheet Relations](https://help.sap.com/docs/leanix/ea/fact-sheet-relations)
        * [Fact Sheet Permissions](https://help.sap.com/docs/leanix/ea/fact-sheet-permissions)
        * [Conditional Attributes](https://help.sap.com/docs/leanix/ea/conditional-attributes)
        * [Fact Sheet Subtype Management](https://help.sap.com/docs/leanix/ea/fact-sheet-subtype-management)
        * [Custom Fact Sheet Types](https://help.sap.com/docs/leanix/ea/custom-fact-sheet-types)
        * [Fact Sheet Order and Colors](https://help.sap.com/docs/leanix/ea/fact-sheet-order-and-colors)
      * [Subscription Roles](https://help.sap.com/docs/leanix/ea/subscription-roles)
      * [Tagging](https://help.sap.com/docs/leanix/ea/tagging)
      * [Dashboards Settings](https://help.sap.com/docs/leanix/ea/dashboards-settings)
    * [Advanced Settings](https://help.sap.com/docs/leanix/ea/advanced-settings)
      * [Automations](https://help.sap.com/docs/leanix/ea/automations)
        * [Automations Best Practices](https://help.sap.com/docs/leanix/ea/automations-best-practices)
          * [Automations Best Practices: Selected Use Cases](https://help.sap.com/docs/leanix/ea/automation-examples-selected-use-cases)
          * [Automations Best Practices: Use Cases by Triggers](https://help.sap.com/docs/leanix/ea/automation-examples-use-cases-by-triggers)
          * [Automations Best Practices: Automations with Webhooks](https://help.sap.com/docs/leanix/ea/automation-examples-automations-with-webhooks)
        * [Automations with Scripts](https://help.sap.com/docs/leanix/ea/automations-with-scripts)
        * [Examples: Automations with Scripts](https://help.sap.com/docs/leanix/ea/examples-automations-with-scripts)
